@@ -65,7 +65,8 @@ def submission_command(config, canvas, args):
       if "less" in pager and ("-R" in pager or "-r" in pager):
         styles = True
       with console.pager(styles=styles):
-        console.print(rich.markdown.Markdown(output))
+        console.print(rich.markdown.Markdown(output,
+                                             code_theme="manni"))
     else:
       print(output)
 def add_submission_options(parser, required=False):
@@ -181,13 +182,10 @@ def format_submission(submission):
     pass
   try:
     for attachment in submission.attachments:
-      if "text/" not in attachment["content-type"]:
+      content_type = ct_to_md(attachment["content-type"])
+      if not content_type:
         continue
 
-      content_type = attachment["content-type"][len("text/"):]
-      if content_type.startswith("x-"):
-        content_type = content_type[2:]
-
       contents = urllib.request.urlopen(attachment["url"]).read().decode("utf8")
 
       formatted_submission += format_section(
@@ -210,6 +208,22 @@ def format_submission(submission):
   return formatted_submission
 def format_section(title, body):
   return f"\n# {title}\n\n{body}\n\n"
+def ct_to_md(content_type):
+  """
+  Takes a content type, returns Markdown code block type.
+  Returns None if not possible.
+  """
+  if content_type.startswith("text/"):
+    content_type = content_type[len("text/"):]
+  else:
+    return None
+
+  if content_type.startswith("x-"):
+    content_type = content_type[2:]
+  if content_type == "python-script":
+    content_type = "python"
+
+  return content_type
 def format_rubric(submission):
   """Format the rubric assessment of the `submission` in readable form."""
 
